@@ -12,7 +12,7 @@ from .credentials.icredentials import ICredentials
 
 
 class Client(metaclass=abc.ABCMeta):
-    logger = logging.Logger = logging.getLogger('uvicorn')
+    logger: logging.Logger = logging.getLogger('uvicorn')
     audience: str = abc.abstractproperty()
     scope: set = abc.abstractproperty()
 
